@@ -1,7 +1,7 @@
 """
     Access functionality for resources.
     
-    :copyright: Copyright 2010-2013 by Nicklas Boerjesson
+    :copyright: Copyright 2010-2014 by Nicklas Boerjesson
     :license: BSD, see LICENSE for details. 
 """
 from urllib.parse import unquote
@@ -135,13 +135,13 @@ class Resources(XML_Translation):
                 _resources_node = _root_node            
 
         if _resources_node.base:
-            self.base_path = os.path.dirname(unquote(_resources_node.base))
+            self.base_path = os.path.dirname(unquote(_resources_node.base.replace('file:///', '')))
         
         self.local_resources = dict()
         
         for _curr_resource_node in _resources_node.findall("resource"):
             
-            if _curr_resource_node.get("uuid") != None:
+            if _curr_resource_node.get("uuid") is not None:
                 self._debug_print("parse_xml: Create new resource object")
                 _new_resource = Resource()
                 _new_resource.uuid = _curr_resource_node.get("uuid")
